import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
//defining X-axis
const render = data => {
  const xValue = d => d.Years; //putting years in x-axis
  const xAxisLabel = 'Years';
  
  //declearing the title of chart
  const title = 'Number of Women in House of Representative';
  //labeling band defining Y-axis
  const yValue = d => d.Women_total; // putting y in yaxis
  const circleRadius = 6;
  const yAxisLabel = 'Total Number of Women';
  //styles of plot
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  //Creating X-scale with years value
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0,innerWidth]) //output values 
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  //creating X-axis
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(10);
  //creating y-axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  //appending yaxis to svg label
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
  	
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  //appending xaxis value to svg
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 50)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //line graph genertor of x and y
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
 	 
  //appending line graph to svg
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
  //appending title to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -15)
  		.attr('x',70)
      .text(title);
};


//geist data is linked 
csv('https://gist.githubusercontent.com/Rinoj-Gautam/c4a1829b3ca4eb1bcc08563853486d2c/raw/50fa319aeab4871337dbe014e03272198a51cdd6/womenincongress.csv')
  .then(data => {
    data.forEach(d => {
      d.Women_total = +d.Women_total;
      d.Years = d.Years;
    });
  //geting the last available rows of data as there are many rows
    if (data) {
      render(data.slice(44, 52));
    }
  
    
  });